Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Execute ¶
func Execute()
Execute adds all child commands to the root command and sets flags appropriately.
func SetVersion ¶ added in v0.3.0
func SetVersion(v, c, d string)
SetVersion sets the application version, commit and build date
Types ¶
Click to show internal directories.
Click to hide internal directories.